@@ -24,11 +24,14 @@ from cfnlint.rules import CloudFormationLintRule as _CloudFormationLintRule
 from cfnlint.rules import ParseError as _ParseError
 from cfnlint.rules import TransformError as _TransformError
 from cfnlint.rules import RuleError as _RuleError
+from cfnlint.decode.node import dict_node
 import cfnlint.rules
 
 LOGGER = logging.getLogger(__name__)
 
 # pylint: disable=too-many-lines
+
+
 def refactored(message):
     """ Decoreate for refactoring classes """
     def cls_wrapper(cls):
@@ -346,7 +349,8 @@ class Template(object):  # pylint: disable=R0904
 
     def search_deep_keys(self, searchText):
         """
-            Search for keys in all parts of the templates
+            Search for a key in all parts of the template.
+            :return if searchText is "Ref", an array like ['Resources', 'myInstance', 'Properties', 'ImageId', 'Ref', 'Ec2ImageId']
         """
         LOGGER.debug('Search for key %s as far down as the template goes', searchText)
         results = []
@@ -745,7 +749,7 @@ class Template(object):  # pylint: disable=R0904
 
             return value
 
-        result = {}
+        result = dict_node({}, obj.start_mark, obj.end_mark)
         if isinstance(obj, dict):
             if len(obj) == 1:
                 if obj.get('Fn::If'):
@@ -753,13 +757,11 @@ class Template(object):  # pylint: disable=R0904
                     if new_value is not None:
                         result = new_value
                 else:
-                    result = {}
                     for key, value in obj.items():
                         new_value = get_value(value, scenario)
                         if new_value is not None:
                             result[key] = new_value
             else:
-                result = {}
                 for key, value in obj.items():
                     new_value = get_value(value, scenario)
                     if new_value is not None:
@@ -767,7 +769,7 @@ class Template(object):  # pylint: disable=R0904
 
         return result
 
-    def get_object_without_conditions(self, obj):
+    def get_object_without_conditions(self, obj, property_names=None):
         """
             Gets a list of object values without conditions included
             Input:
@@ -798,10 +800,16 @@ class Template(object):  # pylint: disable=R0904
                     }
                 ]
         """
+        property_names = [] if property_names is None else property_names
+        o = {}
+        if property_names:
+            for property_name in property_names:
+                o[property_name] = deepcopy(obj.get(property_name))
+        else:
+            o = deepcopy(obj)
         results = []
 
-        scenarios = self.get_conditions_scenarios_from_object([obj])
-
+        scenarios = self.get_conditions_scenarios_from_object([o])
         if not isinstance(obj, dict):
             return results
 
